@@ -5,6 +5,7 @@ import pywikibot
 
 from .constants import *
 from .dataclasses import ExtraProperty, ExtraQualifier, ExtraReference
+from .sentry import *
 from .utils import *
 
 Output = Mapping[str, List[ExtraProperty]]
@@ -16,6 +17,9 @@ class PropertyAdderBot(ABC):
     Supports merging existing properties with the internal representation.
     """
 
+    def __init__(self):
+        load_sentry()
+
     @abstractmethod
     def get_edit_group_id(self) -> Union[str, None]:
         """Get the edit group ID for the bot.
@@ -249,15 +253,19 @@ class PropertyAdderBot(ABC):
                             new_claim, *extra_reference.new_reference_props.values()
                         )
                         acted = True
-        if self.post_output_process_hook(output, item) and not acted:
-            acted = True
+        with start_span(op="post_output_process", name="Post-Output Process Hook"):
+            if self.post_output_process_hook(output, item) and not acted:
+                acted = True
         if acted:
-            self.pre_edit_process_hook(output, item)
-            item.editEntity(
-                summary=self._get_full_summary(item),
-                bot=True,
-            )
-            self.post_edit_process_hook(output, item)
+            with start_span(op="pre_edit_process", name="Pre-Edit Process Hook"):
+                self.pre_edit_process_hook(output, item)
+            with start_span(op="edit_entity", name="Send edit to server"):
+                item.editEntity(
+                    summary=self._get_full_summary(item),
+                    bot=True,
+                )
+            with start_span(op="post_edit_process", name="Post-Edit Process Hook"):
+                self.post_edit_process_hook(output, item)
         return acted
 
     def act_on_item(self, item: EntityPage) -> bool:
@@ -266,7 +274,11 @@ class PropertyAdderBot(ABC):
         :param item: The item to act on.
         :return: If any edits were made to the item.
         """
-        return self.process(self.run_item(item), item)
+        with start_transaction(op="act_on_item", name="Process Item"):
+            with start_span(op="get_output", name="Get Output"):
+                output = self.run_item(item)
+            with start_span(op="process_output", name="Process Output"):
+                return self.process(output, item)
 
     def feed_items(self, items: Iterable[EntityPage]) -> None:
         """Feed items to the bot.
